@@ -367,6 +367,10 @@ namespace apg {
             return basepattern<I>(lab, lab->brand_recurse(hnode), rulestring);
         }
 
+        basepattern<I> onecell() {
+            return basepattern<I>(lab, lab->onecell_recurse(hnode), rulestring);
+        }
+
         // Periodicity detection:
 
         uint64_t digest() {
@@ -633,7 +637,7 @@ namespace apg {
             * Example usage: glider.stream({0,109,255,94,255,255,92,256,135,0})
             */
             int64_t cum = 0;
-            basepattern<I> x = (*this); x -= x;
+            basepattern<I> x(lab, "", rulestring);
             for (uint64_t i = 0; i < spacings.size() - 1; i++) {
                 cum -= spacings[i];
                 x += advance2(cum);
