@@ -262,6 +262,38 @@ class Pattern(object):
 
         return b + x._getbound(direction, pixelsize - 30, offset)
 
+    def component_containing(self, seed=None, halo='ooo$ooo$ooo!'):
+
+        if seed is None:
+            seed = self.onecell()
+
+        if not isinstance(halo, Pattern):
+            halo = self.owner.pattern(halo, self.getrule()).centre()
+
+        if isinstance(seed, tuple):
+            seed = self.owner.pattern('o!', self.getrule())(seed[0], seed[1])
+
+        newptr = self.lifelib('FindConnectedComponent', seed.ptr, self.ptr, halo.ptr)
+        return Pattern(self.session, newptr, self.owner)
+
+    def onecell(self):
+
+        newptr = self.lifelib('GetOneCell', self.ptr)
+        return Pattern(self.session, newptr, self.owner)
+
+    def components(self, halo='ooo$ooo$ooo!'):
+
+        ccs = []
+        x = self
+
+        while (x.nonempty()):
+
+            cc = x.component_containing(halo=halo)
+            x = x - cc
+            ccs.append(cc)
+
+        return ccs
+
     def match(self, live, dead=None, halo=None):
 
         if halo is not None:
